@@ -5,12 +5,14 @@ from xopen import xopen
 
 from . import Sequence
 from ._util import _is_path
+from .interfaces import SingleEndWriter
 
 
 class FileWriter:
     def __init__(
         self,
         file: Union[PathLike, str, BinaryIO],
+        *,
         opener=xopen,
         _close_file: Optional[bool] = None,
     ):
@@ -22,7 +24,7 @@ class FileWriter:
             self._close_on_exit = bool(_close_file)
 
     def __repr__(self) -> str:
-        return "{}({!r})".format(self.__class__.__name__, getattr(self._file, "name", self._file))
+        return f"{self.__class__.__name__}('{getattr(self._file, 'name', self._file)}')"
 
     def close(self) -> None:
         if self._close_on_exit:
@@ -37,7 +39,7 @@ class FileWriter:
         self.close()
 
 
-class FastaWriter(FileWriter):
+class FastaWriter(FileWriter, SingleEndWriter):
     """
     Write FASTA-formatted sequences to a file.
     """
@@ -45,6 +47,7 @@ class FastaWriter(FileWriter):
     def __init__(
         self,
         file: Union[PathLike, str, BinaryIO],
+        *,
         line_length: Optional[int] = None,
         opener=xopen,
         _close_file: Optional[bool] = None,
@@ -57,7 +60,7 @@ class FastaWriter(FileWriter):
         self.line_length = line_length if line_length != 0 else None
 
     def __repr__(self) -> str:
-        return "FastaWriter('{}')".format(getattr(self._file, "name", self._file))
+        return f"FastaWriter('{getattr(self._file, 'name', self._file)}')"
 
     def write(self, name_or_record, sequence: Optional[str] = None):
         """Write an entry to the the FASTA file.
@@ -89,31 +92,41 @@ class FastaWriter(FileWriter):
             self._file.write(text.encode('ascii'))
 
 
-class FastqWriter(FileWriter):
+class FastqWriter(FileWriter, SingleEndWriter):
     """
     Write sequences with qualities in FASTQ format.
 
-    FASTQ files are formatted like this:
-    @read name
-    SEQUENCE
-    +
-    QUALITIS
+    FASTQ files are formatted like this::
+
+        @read name
+        AACCGGTT
+        +
+        FF,:F,,F
     """
     file_mode = 'wb'
 
     def __init__(
         self,
         file: Union[PathLike, str, BinaryIO],
+        *,
         two_headers: bool = False,
         opener=xopen,
         _close_file: Optional[bool] = None,
     ):
         super().__init__(file, opener=opener, _close_file=_close_file)
         self._two_headers = two_headers
-        self.write = self._write_two_headers if self._two_headers else self._write
+        # setattr avoids a complaint from Mypy
+        setattr(self, "write", self._write_two_headers if self._two_headers else self._write)
 
     def __repr__(self) -> str:
-        return "FastqWriter('{}')".format(getattr(self._file, "name", self._file))
+        return f"FastqWriter('{getattr(self._file, 'name', self._file)}')"
+
+    def write(self, record: Sequence) -> None:
+        """
+        Dummy method to make it possible to instantiate this class.
+        The correct write method is assigned in the constructor.
+        """
+        assert False
 
     def _write(self, record: Sequence) -> None:
         """
@@ -130,5 +143,4 @@ class FastqWriter(FileWriter):
         self._file.write(record.fastq_bytes_two_headers())
 
     def writeseq(self, name: str, sequence: str, qualities: str) -> None:
-        self._file.write("@{0:s}\n{1:s}\n+\n{2:s}\n".format(
-            name, sequence, qualities).encode('ascii'))
+        self._file.write(f"@{name:s}\n{sequence:s}\n+\n{qualities:s}\n".encode("ascii"))
