@@ -11,9 +11,9 @@ from pytest import raises, mark
 import dnaio
 from dnaio import (
     FileFormatError, FastaFormatError, FastqFormatError,
-    FastaReader, FastqReader, InterleavedSequenceReader,
-    FastaWriter, FastqWriter, InterleavedSequenceWriter,
-    PairedSequenceReader,
+    FastaReader, FastqReader, InterleavedPairedEndReader,
+    FastaWriter, FastqWriter, InterleavedPairedEndWriter,
+    TwoFilePairedEndReader,
 )
 from dnaio import record_names_match, Sequence
 from dnaio.writers import FileWriter
@@ -35,6 +35,14 @@ class TestSequence:
         with raises(ValueError):
             Sequence(name="name", sequence="ACGT", qualities="#####")
 
+    def test_fastq_bytes(self):
+        assert Sequence("name", "ACGT", "====").fastq_bytes() == \
+            b"@name\nACGT\n+\n====\n"
+
+    def test_fastq_bytes_two_headers(self):
+        assert Sequence("name", "ACGT", "====").fastq_bytes_two_headers() == \
+            b"@name\nACGT\n+name\n====\n"
+
 
 class TestFastaReader:
     def test_file(self):
@@ -231,7 +239,7 @@ class TestFastqReader:
             list(fq)
 
     def test_second_header_not_equal(self):
-        fastq = BytesIO(b'@r1\nACG\n+xy\n')
+        fastq = BytesIO(b'@r1\nACG\n+xy\nXXX\n')
         with raises(FastqFormatError) as info:
             with FastqReader(fastq) as fq:
                 list(fq)  # pragma: no cover
@@ -329,7 +337,7 @@ class TestInterleavedReader:
                 Sequence('read3/2', 'TGTTATTAATATCAAGTTGG', '#HHHHHHHHHHHHHHHHHHH')
             ),
         ]
-        with InterleavedSequenceReader("tests/data/interleaved.fastq") as isr:
+        with InterleavedPairedEndReader("tests/data/interleaved.fastq") as isr:
             reads = list(isr)
 
         assert reads == expected
@@ -340,14 +348,14 @@ class TestInterleavedReader:
     def test_missing_partner(self):
         s = BytesIO(b'@r1\nACG\n+\nHHH\n')
         with raises(FileFormatError) as info:
-            with InterleavedSequenceReader(s) as isr:
+            with InterleavedPairedEndReader(s) as isr:
                 list(isr)
         assert "Interleaved input file incomplete" in info.value.message
 
     def test_incorrectly_paired(self):
         s = BytesIO(b'@r1/1\nACG\n+\nHHH\n@wrong_name\nTTT\n+\nHHH\n')
         with raises(FileFormatError) as info:
-            with InterleavedSequenceReader(s) as isr:
+            with InterleavedPairedEndReader(s) as isr:
                 list(isr)
         assert "Reads are improperly paired" in info.value.message
 
@@ -447,7 +455,7 @@ class TestInterleavedWriter:
             ),
         ]
         bio = BytesIO()
-        with InterleavedSequenceWriter(bio) as writer:
+        with InterleavedPairedEndWriter(bio) as writer:
             for read1, read2 in reads:
                 writer.write(read1, read2)
         assert bio.getvalue() == (
@@ -462,7 +470,7 @@ class TestPairedSequenceReader:
     def test_read(self):
         s1 = BytesIO(b'@r1\nACG\n+\nHHH\n')
         s2 = BytesIO(b'@r2\nGTT\n+\n858\n')
-        with PairedSequenceReader(s1, s2) as psr:
+        with TwoFilePairedEndReader(s1, s2) as psr:
             assert [
                 (Sequence("r1", "ACG", "HHH"), Sequence("r2", "GTT", "858")),
             ] == list(psr)
@@ -470,17 +478,42 @@ class TestPairedSequenceReader:
     def test_record_names_match(self):
         match = record_names_match
         assert match('abc', 'abc')
+        assert match('abc def', 'abc')
+        assert match('abc def', 'abc ghi')
+        assert match('abc', 'abc ghi')
+        assert not match('abc', 'xyz')
+        assert match('abc\tdef', 'abc')
+        assert match('abc\tdef', 'abc\tghi')
+        assert match('abc somecomment\tanothercomment', 'abc andanothercomment\tbla')
+        assert match('abc\tcomments comments', 'abc\tothers others')
+        assert match('abc\tdef', 'abc def')
+
+    def test_record_names_match_with_ignored_trailing_12(self):
+        match = record_names_match
         assert match('abc/1', 'abc/2')
         assert match('abc.1', 'abc.2')
         assert match('abc1', 'abc2')
-        assert not match('abc', 'xyz')
+        assert match('abc2', 'abc1')
+        assert match('abc1 def', 'abc1 ghi')
+        assert match('abc1 def', 'abc2 ghi')
+        assert match('abc2 def', 'abc1 ghi')
+        assert not match('abc1', 'abc4')
+        assert not match('abc1', 'abc')
+        assert not match('abc', 'abc1')
+        assert not match('abc', 'abc2')
+
+    def test_record_names_match_with_ignored_trailing_123(self):
+        match = record_names_match
+        assert match('abc/1', 'abc/3')
+        assert match('abc.1 def', 'abc.3 ghi')
+        assert match('abc.3 def', 'abc.1 ghi')
 
     def test_missing_partner1(self):
         s1 = BytesIO(b'')
         s2 = BytesIO(b'@r1\nACG\n+\nHHH\n')
 
         with raises(FileFormatError) as info:
-            with PairedSequenceReader(s1, s2) as psr:
+            with TwoFilePairedEndReader(s1, s2) as psr:
                 list(psr)
         assert "There are more reads in file 2 than in file 1" in info.value.message
 
@@ -489,32 +522,44 @@ class TestPairedSequenceReader:
         s2 = BytesIO(b'')
 
         with raises(FileFormatError) as info:
-            with PairedSequenceReader(s1, s2) as psr:
+            with TwoFilePairedEndReader(s1, s2) as psr:
                 list(psr)
         assert "There are more reads in file 1 than in file 2" in info.value.message
 
+    def test_empty_sequences_do_not_stop_iteration(self):
+        s1 = BytesIO(b'@r1_1\nACG\n+\nHHH\n@r2_1\nACG\n+\nHHH\n@r3_2\nACG\n+\nHHH\n')
+        s2 = BytesIO(b'@r1_1\nACG\n+\nHHH\n@r2_2\n\n+\n\n@r3_2\nACG\n+\nHHH\n')
+        # Second sequence for s2 is empty but valid. Should not lead to a stop of iteration.
+        with TwoFilePairedEndReader(s1, s2) as psr:
+            seqs = list(psr)
+        print(seqs)
+        assert len(seqs) == 3
+
     def test_incorrectly_paired(self):
         s1 = BytesIO(b'@r1/1\nACG\n+\nHHH\n')
         s2 = BytesIO(b'@wrong_name\nTTT\n+\nHHH\n')
         with raises(FileFormatError) as info:
-            with PairedSequenceReader(s1, s2) as psr:
+            with TwoFilePairedEndReader(s1, s2) as psr:
                 list(psr)
         assert "Reads are improperly paired" in info.value.message
 
 
 @mark.parametrize('path', [
-    'tests/data/simple.fastq',
-    'tests/data/dos.fastq',
-    'tests/data/simple.fasta',
-    'tests/data/with_comment.fasta',
+    os.path.join('tests', 'data', 'simple.fastq'),
+    os.path.join('tests', 'data', 'dos.fastq'),
+    os.path.join('tests', 'data', 'simple.fasta'),
+    os.path.join('tests', 'data', 'with_comment.fasta'),
 ])
 def test_read_stdin(path):
     # Get number of records in the input file
     with dnaio.open(path) as f:
         expected = len(list(f))
 
-    # Use 'cat' to simulate that no file name is available for stdin of the subprocess
-    with subprocess.Popen(['cat', path], stdout=subprocess.PIPE) as cat:
+    # Use piping from a separate subprocess to force the input file name to be unavailable
+    cmd = "type" if sys.platform == "win32" else "cat"
+    with subprocess.Popen(
+        [cmd, path], stdout=subprocess.PIPE, shell=sys.platform == "win32"
+    ) as cat:
         with subprocess.Popen(
             [sys.executable, 'tests/read_from_stdin.py'], stdin=cat.stdout, stdout=subprocess.PIPE
         ) as py:
